@@ -1,4 +1,4 @@
-use crate::program::BfInstruction;
+use crate::frontend::int_program::BfInstruction;
 
 pub fn merge_instructions(_a: &BfInstruction, _b: &BfInstruction) -> Option<BfInstruction> {
     None
